#
# spec file for package gama
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2024 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gama
Version:        2.30
Release:        1.1
Summary:        Adjustment of geodetic networks
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Other
URL:            https://www.gnu.org/software/gama/
# git: http://git.savannah.gnu.org/cgit/gama.git
Source:         http://ftp.gnu.org/pub/gnu/%{name}/%{name}-%{version}.tar.gz
Source2:        http://ftp.gnu.org/pub/gnu/%{name}/%{name}-%{version}.tar.gz.sig
Source3:        https://savannah.gnu.org/people/viewgpg.php?user_id=3448#/%{name}.keyring
Source4:        %{name}-rpmlintrc
BuildRequires:  gcc-c++
BuildRequires:  libxml2-tools
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(expat) >= 1.1
BuildRequires:  pkgconfig(sqlite3)
# for xmllint
Requires:       libxml2-tools

%description
GNU Gama is a project dedicated to adjustment of geodetic
networks. It is intended for use with traditional geodetic
surveyings which are still used and needed in special measurements
(e.g., underground or high precision engineering measurements)
where the Global Positioning System (GPS) cannot be used.

Adjustment in local Cartesian coordinate systems is fully
supported by a command-line program gama-local that adjusts
geodetic (free) networks of observed distances, directions,
angles, height differences, 3D vectors and observed coordinates
(coordinates with given variance-covariance matrix). Adjustment in
global coordinate systems is supported only partly as a gama-g3
program.

%prep
%autosetup -p1

%build
%configure
%make_build

%install
%make_install

%check
%make_build tests

%files
%license COPYING
%doc ChangeLog* README.md NEWS AUTHORS
%{_bindir}/*
%{_infodir}/%{name}.info%{?ext_info}

%changelog
* Sat Mar 23 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 2.30:
  * improved doxygen handling, documentation updates
* Sat Feb 24 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 2.29:
  * New helper program compare-xyz used in testsuite
  * Helper programs other than the main programs gama-local and
    gama-g3 were assigned their own minon versions
* Sun Jan 14 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 2.28:
  * developer visible changes
* Sun Nov 12 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 2.27:
  * Fix a bug in two test suite functions in the Krumm examples
    collection.
  * Update version of krumm/2D/Wolf_DistanceDirectionAngle_free.xml
* Tue Oct  3 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 2.26:
  * Fixed the buggy GNU_gama::local::SVG class
* Sun Aug 27 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 2.25:
  * new program gama-local-deformation for processing two
    adjustment epochs to calculate potential points position
    changes (shift vectors).
  * change from c++11 version to c++14
  * New glossary of basic terms used in gama-local text output and
    in documentation.
* Sun Feb 19 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 2.24:
  * new testing data to gama-g3 test suite
  * xml/gnu-gama-data.xsd version 1.01, new tags
* Thu Dec 22 2022 Dirk Müller <dmueller@suse.com>
- update to 2.23:
  * Fixed the bug in gama-local reading sqlite3 database.  The bug was
    introduced after version 2.10 when testing shell scripts were
    updated to be generated from templates .sh_ files (testing
    templates .sh_ use symbolic names like @INPUT_FILES@ or $RES etc).
  * More readeable output format in check_xml_coordinates.cpp test.
* Sun Sep  4 2022 Andreas Stieger <andreas.stieger@gmx.de>
- GNU Gama 2.22:
  * fixes to XML adjustment ouput format
  * New gama-local adjustment XML output definition
    gama-local-adjustment.xsd version 1.02
* Wed Jul 13 2022 Andreas Stieger <andreas.stieger@gmx.de>
- GNU Gama 2.21:
  * New algorithm ICGS in the class AdjGSO replaced the former
    algorithm MGS.
* Fri Apr 29 2022 Andreas Stieger <andreas.stieger@gmx.de>
- GNU Gama 2.19:
  * Fix a bug in HTML output of adjustment results for GNSS vectors
    in inconsistent coordinate systems
* Fri Apr 15 2022 Andreas Stieger <andreas.stieger@gmx.de>
- GNU gama 2.18:
  * New conversion class K2gkf (lib/krumm) with accompanying
    program krumm2gama-local to support Krumm input data Format
* Fri Jan  7 2022 Andreas Stieger <andreas.stieger@gmx.de>
- GNU gama 2.17:
  * library libgama changed from OBJECTS to static in CMakeLists.txt
  * minor changes needed by qgama to implement xml input format export
  * new function Observation::raw_value()
* Sat Nov 27 2021 Andreas Stieger <andreas.stieger@gmx.de>
- GNU gama 2.16:
  * gama-local option --export renamed from --updated-xml
* Thu Sep 23 2021 Andreas Stieger <andreas.stieger@gmx.de>
- GNU gama 2.15:
  * developer visible changes only
* Tue Mar  2 2021 Andreas Stieger <andreas.stieger@gmx.de>
- GNU gama 2.14:
  * Fix html in Qgama
* Fri Jan 15 2021 Andreas Stieger <andreas.stieger@gmx.de>
- GNU gama 2.13:
  * Command line programs gama-local, gama-local-yaml2gkf and
    gama-local-gkf2yaml can now read input data from standard
    input
  * New exlicit parameter --input-xml in gama-local
  * Fixed implicit model for distance stddev (gama-local
    adjustment model)
  * Fixed new attribute angular in documentation
* Fri Dec 25 2020 Wang Jun <jgwang@suse.de>
- Update to version 2.12
  * Alternative support of input data based on YAML format. YAML
    support was added for gama-local as an alternative to the existing
    XML input format. The YAML support is currently limited only to a
    conversion program gama-local-yaml2gkf but it may be fully
    integrated in gama-local program later.
* Wed Oct 28 2020 Andreas Stieger <andreas.stieger@gmx.de>
- update to 2.11:
  * developer visible changes only
* Sun Sep 27 2020 Andreas Stieger <andreas.stieger@gmx.de>
- update to 2.10:
  * Adjustment results output in Octave format (.m file) with
    independent test of adjustment results (regularization of
    singular systems by the set of constraints)
  * update-constrained-coordinates parameter removed from the input
    XML data format
- fix incorrect dependency warning via gama-rpmlintrc:
  libxml2-tools is a tools package, not a library
* Sat Aug  1 2020 Andreas Stieger <andreas.stieger@gmx.de>
- update to 2.09:
  * Implicit value of XML parameter update_constrained_coordinates
    was changed to yes
* Sat Jun 27 2020 Andreas Stieger <andreas.stieger@gmx.de>
- update to 2.08:
  * updated tests
  * code cleanup
* Fri Sep  6 2019 Andreas Stieger <andreas.stieger@gmx.de>
- update to 2.07:
  * Fixed some bugs in AcordPolar and AcordTraverse classes
  * More algorithms in Acord2 class
* Thu Aug  1 2019 Andreas Stieger <andreas.stieger@gmx.de>
- update to 2.06:
  * Acord2 for more robust handling of data
* Wed Feb 20 2019 Andreas Stieger <andreas.stieger@gmx.de>
- update to 2.03:
  * The new attribute "extern" was added both to the gama-local xml
    input and adjustment results xml output to be conformant with
    an external database project. Information supplied in "extern"
    attributes of observations are not processed in any way in
    gama-local and are only passively transfered to XML adjustement
    output.
* Fri Dec 21 2018 astieger@suse.com
- update to 2.02:
  * Improve Hungarian translation
* Mon Oct  8 2018 astieger@suse.com
- update to 2.01:
  * Conditional build for gama-g3 enabled implicitly
  * XML schema definition for gama-g3 adjustment results with
    new xmllint testsuite
* Fri May 25 2018 astieger@suse.com
- update to 2.00:
  * Kolmogorov-Smirnov test removed - available only as conditional
    compile
  * various code level fixes
* Fri Mar 30 2018 astieger@suse.com
- update to 1.22:
  * code clean-up and various developer visible changes
* Wed Nov 15 2017 astieger@suse.com
- update to 1.20:
  * New test suite for matvec classes and support for valgrind
    memory leak tests for tests/matvec and tests/gama-local.
  * This release is a preperation phase for the next release in
    which the base matvec memory handling class (MemRep) will
    reimplemented with C++11 move constructor and move assignemnt
    operator.
* Mon Sep 18 2017 astieger@suse.com
- update to 1.19:
  Fix implicit value of covariance band in XML adjustment output
  being -1 (full bandwidth)
* Thu Jan 19 2017 astieger@suse.com
- update to 1.18:
  * fixed a formatting bug in outlaying terms (due to c++11)
  * fixed a bug in HTML parser test
  * simplified class LocalPoint
  * fixed a bug in sql export
  * added @documentencoding UTF-8 into gama.texi
* Mon Nov  9 2015 astieger@suse.com
- update to 1.17:
  * minor fixes in documentation
  * fixed a bug in SQL schema
  * new export of XML network definition
  * C++11 features enabled (-std=c++11 for g++ compiler)
  * fixed several minor bugs
* Sat Aug 22 2015 astieger@suse.com
- initial package
